From 311f6832fe62325b982bbf20186f35c7e8ef4a72 Mon Sep 17 00:00:00 2001
From: blsaws <bs3131@att.com>
Date: Sun, 10 Apr 2016 21:16:03 -0700
Subject: Correct column name in security group rules table

JIRA: COPPER-4

Change-Id: Ib85f1d12c71368cc73fe152df465a8507c6ec49c
Signed-off-by: blsaws <bs3131@att.com>
---
 components/congress/test-webapp/www/html/congress_translators.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'components/congress')

diff --git a/components/congress/test-webapp/www/html/congress_translators.js b/components/congress/test-webapp/www/html/congress_translators.js
index 466379e..eeb2934 100644
--- a/components/congress/test-webapp/www/html/congress_translators.js
+++ b/components/congress/test-webapp/www/html/congress_translators.js
@@ -361,8 +361,8 @@ var TRANSLATORS = [];
         'selector-type': 'DICT_SELECTOR',
         'in-list': true,
         'field-translators':
-// TODO: Port ID added to complete table translation
-            [{'fieldname': 'port id', 'translator': value_trans},
+// TODO: Security group ID added to complete table translation
+            [{'fieldname': 'security_group_id', 'translator': value_trans},
              {'fieldname': 'id', 'translator': value_trans},
              {'fieldname': 'tenant_id', 'translator': value_trans},
              {'fieldname': 'remote_group_id', 'translator': value_trans},
-- 
cgit